@@ -8,7 +8,7 @@ use File::Copy;
 
 use DBIx::FileStore::ConfigFile;
 
-our $VERSION = '0.31';  # version also mentioned in POD below.
+our $VERSION = '0.32';  # version also mentioned in POD below.
 use Mouse;
 
 has 'dbuser' =>     ( is=>'rw', isa=>'Str', default=>build_value_sub('dbuser', 'root') );
@@ -38,9 +38,8 @@ sub build_value_sub {
 
 sub build_config_hash {
     my $self = shift; 
-    #warn "$0: IN BUILD_CONFIG_HASH\n";
-    my $config_file = $self->config_file();
     my $config_reader = new DBIx::FileStore::ConfigFile();
+    my $config_file = $self->config_file();
     my $hash =  $config_reader->read_config_file( $config_file ? ($config_file) : () );
     return $hash;
 }
@@ -203,9 +202,9 @@ sub write_from_filehandle_to_db {
     my $size = 0;
 
     $self->_lock_tables();
-    for( my ($bytes,$part,$block) = (0,0,"");           # init
-    $bytes = read($fh, $block, $self->blocksize);    # test 
-    $part++, $block="" ) {                              # increment
+    for( my ($bytes,$part,$block) = (0,0,"");        # init our three vars
+    $bytes = read($fh, $block, $self->blocksize);    # test that we read something
+    $part++, $block="" ) {                           # increment $part and reset $block
         $ctx->add( $block );
         $size += length( $block );
         my $b_md5 = md5_base64( $block );
@@ -329,7 +328,7 @@ DBIx::FileStore - Module to store files in a DBI backend
 
 =head1 VERSION
 
-Version 0.31
+Version 0.32
 
 =head1 SYNOPSIS
 
